# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/classifieds/advertising/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/classifieds/advertising/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Classifieds\\Advertising\\": "packages/classifieds/advertising/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Classifieds\Advertising\Providers\AdvertisingServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Advertising'  => Classifieds\Advertising\Facades\Advertising::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Classifieds\\AdvertisingTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Classifieds\Advertising\Providers\AdvertisingServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Classifieds\Advertising\Providers\AdvertisingServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Classifieds\Advertising\Providers\AdvertisingServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/advertising/{modulename}

**User**

    http://path-to-route-folder/user/advertising/{modulename}

**Public**

    http://path-to-route-folder/advertisings


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/advertising/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/advertising/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/advertising/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/advertising/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/advertising/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/advertising/{modulename}/{slug}
    METHOD: GET